@@ -61,6 +61,8 @@ def sort_classes(classes):
                     cdict[cl.__name__] = cl
                     lst.append(cl)
                 cldeps.append(cl.__name__)
+        if hasattr(cls, "_depends_on"):
+            cldeps.extend(cls._depends_on)
         deps[cls.__name__] = cldeps
     lst, has_cycle = topological_sort(deps)
     if has_cycle:
@@ -388,7 +390,7 @@ class Arg:
 
 
 class Kernel:
-    def __init__(self, args, c_name=None, ret=None, n_threads=None):
+    def __init__(self, args, c_name=None, ret=None, n_threads=1):
         self.c_name = c_name
         self.args = args
         self.ret = ret
@@ -404,9 +406,10 @@ class Kernel:
 
 
 class Method:
-    def __init__(self, kernel_name, arg_name="self"):
-        self.kernel_name = kernel_name
-        self.arg_name = arg_name
+    def __init__(self, args, c_name, ret):
+        self.args = args
+        self.c_name = c_name
+        self.ret = ret
 
     def mk_method(self):
         def a_method(instance, *args, **kwargs):
