@@ -19,6 +19,9 @@ class MetaRef(type):
 
 
 class Ref(metaclass=MetaRef):
+
+    _has_refs = True
+
     def __init__(self, reftype):
         self._reftype = reftype
         self.__name__ = "Ref" + self._reftype.__name__
@@ -102,6 +105,8 @@ class MetaUnionRef(type):
         if "_methods" not in data:
             data["_methods"] = []
 
+        data['_has_refs'] = True
+
         return type.__new__(cls, name, bases, data)
 
     def _is_member(cls, value):
